<?php

namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use FM\Service\HierarquiaUsuariosService;
use FM\Traits\TResponse;

class HierarquiaUsuariosController extends FMCrud
{

    use TResponse;

    protected $HierarquiaUsuariosService;

    public function __construct($crudService, $environment, HierarquiaUsuariosService $HierarquiaUsuariosService)
    {
        parent::__construct($crudService, $environment);
        $this->HierarquiaUsuariosService = $HierarquiaUsuariosService;
    }

    public function getHierarquia()
    {
        try {
            $data = $this->HierarquiaUsuariosService->getHierarquia();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getHierarquiaDetalhes(Request $request)
    {
        try {
            $data = $this->HierarquiaUsuariosService->getHierarquiaDetalhes($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getHierarquiaFacilities(Request $request)
    {
        try {
            $data = $this->HierarquiaUsuariosService->getHierarquiaFacilities($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getHierarquiaUsuarios(Request $request)
    {
        try {
            $data = $this->HierarquiaUsuariosService->getHierarquiaUsuarios($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getHierarquiaPais(Request $request)
    {
        try {
            $data = $this->HierarquiaUsuariosService->getHierarquiaPais($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirUsuarios(Request $request)
    {
        try {
            $data = $this->HierarquiaUsuariosService->inserirUsuarios($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function salvarHierarquia(Request $request)
    {
        try {
            $data = $this->HierarquiaUsuariosService->salvarHierarquia($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function excluirHierarquia(Request $request)
    {
        try {
            $params = $request->getParameters();
            $data = $this->HierarquiaUsuariosService->excluirHierarquia($params);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function excluirUsuarios(Request $request)
    {
        try {
            $params = $request->getParameters();
            $data = $this->HierarquiaUsuariosService->excluirUsuarios($params);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // Hierarquia por local

    public function inserirHierarquiaLocal(Request $request)
    {
        try {
            $data = $this->HierarquiaUsuariosService->inserirHierarquiaLocal($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getLocalHierarquia()
    {
        try {
            $data = $this->HierarquiaUsuariosService->getLocalHierarquia();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getHierarquiaLocal()
    {
        try {
            $data = $this->HierarquiaUsuariosService->getHierarquiaLocal();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
