<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class Fm00000000HabilidadesFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    // QUERY FRAME PRINCIPAL HABILIDADES
    public function getHabilidades()
    {
        $sql = "SELECT NRHABILIDADE, NMHABILIDADE, IDATIVO FROM FCM_HABILIDADE";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function inserirHabilidade($params)
    {
        $sql = "INSERT INTO FCM_HABILIDADE (
            NRHABILIDADE, NMHABILIDADE, IDATIVO, NRORG, CDOPERINCLUSAO,NRORGINCLUSAO, DTINCLUSAO
        ) VALUES (
            :NRHABILIDADE, :NMHABILIDADE, :IDATIVO, :NRORG, :CDOPERINCLUSAO, :NRORGINCLUSAO, SYSDATE
        )";

        $this->connection->executeStatement($sql, $params);
    }

    public function atualizarHabilidade($params)
    {
        $sql = "UPDATE FCM_HABILIDADE 
                SET NMHABILIDADE    = :NMHABILIDADE,
                    CDOPERULTATU    = :CDOPERULTATU,
                     NRORGULTATU    = :NRORGULTATU,
                        DTULTATU    = SYSDATE
              WHERE NRHABILIDADE    = :NRHABILIDADE";

        $this->connection->executeStatement($sql, $params);
    }

    public function excluirHabilidades($parametro)
    {
        $sql = "DELETE FROM FCM_HABILIDADE 
                 WHERE NRHABILIDADE IN (" . $parametro . ")";

        $this->connection->executeStatement($sql);
    }

    // QUERY TAB OEPRADORES
    public function getOperadorHabilidade($params)
    {
        $sql = "SELECT NRRELACHABOPER, NRHABILIDADE, CDOPERADOR 
                   FROM FCM_RELACHABOPER
                  WHERE NRHABILIDADE = :NRHABILIDADE";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function relacionarOperadorHabilidade($params)
    {
        $sql = "INSERT INTO FCM_RELACHABOPER (
           NRRELACHABOPER, NRHABILIDADE, CDOPERADOR, NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO, DTINCLUSAO
        ) VALUES (
            :NRRELACHABOPER, :NRHABILIDADE, :CDOPERADOR, :NRORG, :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO, SYSDATE
        )";

        $this->connection->executeStatement($sql, $params);
    }

    public function excluirOperadorHabilidades($filtro)
    {
        $sql = "DELETE FROM FCM_RELACHABOPER
                $filtro";

        $this->connection->executeStatement($sql);
    }

    // QUERY TAB ATIVIDADES
    public function getAtividadeHabilidade($params)
    {
        $sql = "SELECT FCM_TAREFA.NMTAREFA, FCM_RELACHABATIV .NRRELACHABATIV, FCM_TAREFA.NRTAREFA 
                FROM FCM_RELACHABATIV 
                 LEFT JOIN  FCM_TAREFA
                    ON FCM_RELACHABATIV.NRTAREFA = FCM_TAREFA.NRTAREFA
                 WHERE FCM_RELACHABATIV.NRHABILIDADE IN (" . $params . ")";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function relacionarAtividadeHabilidade($params)
    {
        $sql = "INSERT INTO FCM_RELACHABATIV (
           NRRELACHABATIV, NRTAREFA, NRHABILIDADE, NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO, DTINCLUSAO
        ) VALUES (
            :NRRELACHABATIV, :NRTAREFA, :NRHABILIDADE, :NRORG, :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO, SYSDATE
        )";

        $this->connection->executeStatement($sql, $params);
    }

    public function excluirAtividadeHabilidades($filtro)
    {
        $sql = "DELETE FROM FCM_RELACHABATIV
                $filtro";

        $this->connection->executeStatement($sql);
    }

    public function getAtividadesEmUso($param)
    {
        $sql = "SELECT DISTINCT * FROM FCM_TAREFAAGEND
        JOIN FCM_TAREFACHK ON FCM_TAREFAAGEND.NRTAREFACHK = FCM_TAREFACHK.NRTAREFACHK
        JOIN FCM_TAREFA ON FCM_TAREFA.NRTAREFA = FCM_TAREFACHK.NRTAREFA
        JOIN FCM_RELACHABATIV ON FCM_TAREFA.NRTAREFA = FCM_RELACHABATIV.NRTAREFA
        WHERE FCM_RELACHABATIV.NRRELACHABATIV IN (" . $param . ")";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }
}
