<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class Fm00010000ParametrizacaoGeralFactory
{

    use TQuery;

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function inserirParametrizacao($params)
    {
        $sql = "INSERT INTO FCM_PARAMGERAL (
                    NRPARAMGERAL,           NRORG,                  IDATIVO,                    CDOPERINCLUSAO, 
                    NRORGINCLUSAO,          IDUTILIZAGEOLOCAL,      IDUTILIZAGEOLOCALINITAR,    IDHABILITAOFFLINE, 
                    IDTIPOCARREGAOFFLINE,   QTDIASCARREGAOFFLINE,   DTINICARREGAOFFLINE,        DTFIMCARREGAOFFLINE, 
                    IDNOTIFNAOCONFORM,      LISTNOTIFNAOCONFORM,    EMAILSNOTIFNAOCONFROM,      IDENCERRAAUTO,
                    QTDDIASENCERRAAUTO
                )
                VALUES (
                    :NRPARAMGERAL,          :NRORG,                 :IDATIVO,                   :CDOPERINCLUSAO,
                    :NRORGINCLUSAO,         :IDUTILIZAGEOLOCAL,     :IDUTILIZAGEOLOCALINITAR,   :IDHABILITAOFFLINE, 
                    :IDTIPOCARREGAOFFLINE,  :QTDIASCARREGAOFFLINE,  :DTINICARREGAOFFLINE,       :DTFIMCARREGAOFFLINE,
                    :IDNOTIFNAOCONFORM,     :LISTNOTIFNAOCONFORM,   :EMAILSNOTIFNAOCONFROM,     :IDENCERRAAUTO,
                    :QTDDIASENCERRAAUTO
                )";
        
        $this->connection->executeStatement($sql, $params);
    }

    public function inserirParametrizacaoTarefa($params)
    {
        $sql = "INSERT INTO FCM_PARAMGERAL (NRPARAMGERAL,  NRORG, IDATIVO, CDOPERINCLUSAO, NRORGINCLUSAO, IDVALIDACRIATAREFA, IDUTILIZAHABILIDADE, IDVALIDACONFLITOURG, EMAILSNOTIFALHTRANSFER)
                     VALUES (:NRPARAMGERAL, :NRORG,  'S', :CDOPERINCLUSAO, :NRORGINCLUSAO, :IDVALIDACRIATAREFA, :IDUTILIZAHABILIDADE, :IDVALIDACONFLITOURG, :EMAILSNOTIFALHTRANSFER)";
        
        $this->connection->executeStatement($sql, $params);
    }

    public function updateParametrizacaoTarefa($params)
    {
        
        $sql = "UPDATE FCM_PARAMGERAL 
                    SET CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE,
                        IDUTILIZAHABILIDADE = :IDUTILIZAHABILIDADE,
                        IDVALIDACONFLITOURG = :IDVALIDACONFLITOURG,
                        IDVALIDACRIATAREFA  = :IDVALIDACRIATAREFA,
                        EMAILSNOTIFALHTRANSFER = :EMAILSNOTIFALHTRANSFER
                WHERE NRPARAMGERAL = :NRPARAMGERAL";
        
        $this->connection->executeStatement($sql, $params);
    }


    public function updateParametrizacao($params)
    {
        
        $sql = "UPDATE FCM_PARAMGERAL 
                  SET CDOPERULTATU        = :CDOPERULTATU,
                  IDUTILIZAGEOLOCAL       = :IDUTILIZAGEOLOCAL,
                  IDUTILIZAGEOLOCALINITAR = :IDUTILIZAGEOLOCALINITAR,
                  IDHABILITAOFFLINE       = :IDHABILITAOFFLINE,
                  DTINICARREGAOFFLINE     = :DTINICARREGAOFFLINE,
                  DTFIMCARREGAOFFLINE     = :DTFIMCARREGAOFFLINE,
                  QTDIASCARREGAOFFLINE    = :QTDIASCARREGAOFFLINE,
                  NRPARAMGERAL            = :NRPARAMGERAL,
                  IDTIPOCARREGAOFFLINE    = :IDTIPOCARREGAOFFLINE,
                  IDATIVO                 = :IDATIVO,
                  NRORGULTATU             = :NRORGULTATU,
                  DTULTATU                = SYSDATE,
                  IDNOTIFNAOCONFORM       = :IDNOTIFNAOCONFORM,
                  LISTNOTIFNAOCONFORM     = :LISTNOTIFNAOCONFORM,
                  EMAILSNOTIFNAOCONFROM   = :EMAILSNOTIFNAOCONFROM,
                  IDENCERRAAUTO           = :IDENCERRAAUTO,
                  QTDDIASENCERRAAUTO      = :QTDDIASENCERRAAUTO
                WHERE NRPARAMGERAL = :NRPARAMGERAL";
        
        $this->connection->executeStatement($sql, $params);
    }

    public function getParametrizacoes()
    {
        $sql = "SELECT NRPARAMGERAL, IDVALIDACRIATAREFA, IDUTILIZAGEOLOCAL, IDUTILIZAGEOLOCALINITAR, IDHABILITAOFFLINE,
                       IDTIPOCARREGAOFFLINE, QTDIASCARREGAOFFLINE, TO_CHAR(DTINICARREGAOFFLINE, 'DD/MM/YY') DTINICAL,
                       IDNOTIFNAOCONFORM, LISTNOTIFNAOCONFORM, EMAILSNOTIFNAOCONFROM,
                       TO_CHAR(DTFIMCARREGAOFFLINE, 'DD/MM/YY') DTFINAL, IDUTILIZAHABILIDADE, IDVALIDACONFLITOURG, EMAILSNOTIFALHTRANSFER,
                       IDENCERRAAUTO, QTDDIASENCERRAAUTO
                FROM FCM_PARAMGERAL";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getMascara()
    {

        $sql = "SELECT IDOBRIGACDLOCAT, IDUTILIZAMASCCDLOCAT, DSMASCCDLOCAT, IDALTERAMASCCDLOCAT 
                FROM FCM_PARAMGERAL";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function updateMascara($params)
    {
        $sql = "UPDATE FCM_PARAMGERAL 
                SET IDOBRIGACDLOCAT = :IDOBRIGACDLOCAT,
                IDUTILIZAMASCCDLOCAT = :IDUTILIZAMASCCDLOCAT,
                DSMASCCDLOCAT = : DSMASCCDLOCAT,
                IDALTERAMASCCDLOCAT = : IDALTERAMASCCDLOCAT,
                NRORGINCLUSAO = :NRORGINCLUSAO,
                DTULTATU = SYSDATE,
                CDOPERULTATU = :CDOPERULTATU,
                NRORGULTATU = :NRORGULTATU";

        $this->connection->executeStatement($sql, $params);
    }

    public function getCountMascara()
    {

        $sql = "SELECT COUNT(NRPARAMGERAL) AS QTA 
                FROM FCM_PARAMGERAL";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    // INTEGRAÇÃO COM SM
    public function validarItem($parametros)
    {

        $sql = "SELECT COUNT(*) CONT
                    FROM FCM_RELSERVITEMTAR
                    WHERE CDSERVORCA = :CDSERVORCA
                    AND CDTPMEDIDASERV = :CDTPMEDIDASERV
                    AND NRATIVIDADE = :NRATIVIDADE
                    AND IDATIVO = 'S'";

        $retorno = $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
        return $retorno[0]['CONT'];
    }

    public function inserirRelacionamento($parametros)
    {

        $sql = "INSERT INTO FCM_RELSERVITEMTAR(NRRELSERVITEMTAR, CDSERVORCA, CDTPMEDIDASERV, NRATIVIDADE, IDATIVO, 
                                               NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
                VALUES (:NRRELSERVITEMTAR, :CDSERVORCA, :CDTPMEDIDASERV, :NRATIVIDADE, 'S' , :NRORG, SYSDATE, 
                        :CDOPERINCLUSAO, :NRORGINCLUSAO)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getRelacionamentoServicoTipoMedida()
    {

        $sql = "SELECT  ROWNUM AS ID, RELACIONAMENTO.* 
                    FROM (SELECT DISTINCT FCM_RELSERVITEMTAR.CDSERVORCA, FCT_SERVICOORCA.NMSERVORCA, FCM_RELSERVITEMTAR.CDTPMEDIDASERV, FCT_TIPOMEDIDASERV.DSTPMEDIDASERV
                    FROM FCM_RELSERVITEMTAR
                    JOIN FCT_TIPOMEDIDASERV
                        ON FCT_TIPOMEDIDASERV.CDTPMEDIDASERV = FCM_RELSERVITEMTAR.CDTPMEDIDASERV
                    JOIN FCT_SERVICOORCA
                        ON FCT_SERVICOORCA.CDSERVORCA = FCM_RELSERVITEMTAR.CDSERVORCA
                        WHERE FCM_RELSERVITEMTAR.IDATIVO = 'S') RELACIONAMENTO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getItensRelacionamentoServicoTipoMedida($parametros)
    {

        $sql = "SELECT FCM_RELSERVITEMTAR.NRRELSERVITEMTAR, FCM_ATIVIDADE.NRATIVIDADE, FCM_ATIVIDADE.NMATIVIDADE 
                        FROM FCM_RELSERVITEMTAR
                        JOIN FCM_ATIVIDADE 
                          ON FCM_ATIVIDADE.NRATIVIDADE = FCM_RELSERVITEMTAR.NRATIVIDADE
                       WHERE FCM_RELSERVITEMTAR.CDTPMEDIDASERV = :CDTPMEDIDASERV
                         AND FCM_RELSERVITEMTAR.CDSERVORCA = :CDSERVORCA
                         AND FCM_RELSERVITEMTAR.IDATIVO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function inativarServicos($parametros)
    {

        $sql = "UPDATE FCM_RELSERVITEMTAR
                    SET IDATIVO = 'N',
                        DTULTATU = SYSDATE,
                        CDOPERULTATU =:CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU
                    WHERE CDSERVORCA = :CDSERVORCA
                    AND CDTPMEDIDASERV = :CDTPMEDIDASERV";

        $this->connection->executeStatement($sql, $parametros);
    }

    // ------- PARAMETRIZAÇÃO GEOLOCALIZAÇÃO ----------
    public function getGeolocalizacao()
    {
        $sql = "SELECT IDUTILIZAGEOLOCAL, IDUTILIZAGEOLOCALINITAR
        FROM FCM_PARAMGERAL";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getPrioridades()
    {
        $sql = "SELECT NRPRIORIDADETAREFA, NMPRIORIDADETAREFA, IDPRIORIDADE, ATRASOPERMITIDO, IDATIVO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO
        FROM FCM_PRIORIDADETAREFA
        ORDER BY NRPRIORIDADETAREFA ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertPrioridade($parametros)
    {
        $sql = "INSERT INTO FCM_PRIORIDADETAREFA (NRPRIORIDADETAREFA, NMPRIORIDADETAREFA, IDPRIORIDADE, ATRASOPERMITIDO, IDATIVO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
        VALUES (:NRPRIORIDADETAREFA, :NMPRIORIDADETAREFA, :IDPRIORIDADE, :ATRASOPERMITIDO, :IDATIVO, :NRORG, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO)";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function updatePrioridade($parametros)
    {
        $sql = "UPDATE FCM_PRIORIDADETAREFA
                        SET NMPRIORIDADETAREFA = :NMPRIORIDADETAREFA,
                            IDPRIORIDADE = :IDPRIORIDADE,
                            ATRASOPERMITIDO = :ATRASOPERMITIDO,
                            IDATIVO = :IDATIVO,
                            DTULTATU = SYSDATE,
                            CDOPERULTATU = :CDOPERULTATU,
                            NRORGULTATU = :NRORGULTATU
            WHERE NRPRIORIDADETAREFA = :NRPRIORIDADETAREFA";

        $this->connection->executeStatement($sql, $parametros);
    }

    // ENCERRAMENTO AUTOMÁTICO DE SOLICITAÇÕES
    public function getParametrizacaoSolicitacoesAuto($entityManager)
    {
        $sql = "SELECT IDENCERRAAUTO, QTDDIASENCERRAAUTO
                FROM FCM_PARAMGERAL";

        $retorno = $entityManager->getConnection()->fetchAll($sql);
        return $retorno[0];
    }

    public function getSolicitacoesEncerrar($parametros, $entityManager)
    {
        $sql = "SELECT SOL.NRSOLICITACAO, SOL.NMSOLICITACAO, SOL.CDOPERABERTURA
                FROM FCM_SOLICITACAO SOL
                JOIN FCM_SOLICITACAOHISTORICO SOLHIST ON SOLHIST.NRSOLICITACAO = SOL.NRSOLICITACAO
                WHERE SYSDATE - :QTDDIASENCERRAAUTO > SOLHIST.DTINCLUSAO
                AND SOL.IDSITUACAO = 3
                AND SOLHIST.IDSITUACAO = 3";

        return $entityManager->getConnection()->fetchAll($sql, $parametros);
    }

    public function atualizaSituacaoAutomaticamente($parametros, $entityManager)
    {
        $sql = "UPDATE FCM_SOLICITACAO
                SET IDSITUACAO = 4
                WHERE NRSOLICITACAO = :NRSOLICITACAO";

        $entityManager->getConnection()->executeStatement($sql, $parametros);
    }

    public function insereHistoricoAutomaticamente($parametros, $entityManager)
    {
        $sql = "INSERT INTO FCM_SOLICITACAOHISTORICO (
                    NRSOLICITACAOHISTORICO, NRSOLICITACAO,      NMSOLICITACAO,      DTHISTSOLICITACAO,
                    IDSITUACAO,             IDTIPOHISTORICO,    DSSOLICITACAO,      NRORG,
                    DTINCLUSAO,             DTULTATU,           CDOPERSOLICITANTE
                )
                VALUES (
                    :NRSOLICITACAOHISTORICO, :NRSOLICITACAO,    :NMSOLICITACAO,     SYSDATE,
                    :IDSITUACAO,             :IDTIPOHISTORICO,  :DSSOLICITACAO,     :NRORG,
                    SYSDATE,                 SYSDATE,           :CDOPERSOLICITANTE
                )";

        $entityManager->getConnection()->executeStatement($sql, $parametros);
    }
}
