/* Tabela ENDEFILI: Endereo da Filial*/
/* Descrio: A trigger insere registros na tabela ALTERAPARTSPED a partir de alteraes
na tabela ENDEFILI */
/* Objetivo: Registrar as alteraes realizadas nos campos CDPAIS, CDMUNICIPIO, DSENDEFILI, DSCOMPENDFIL, NMBAIRFILI 
da tabela ENDEFILI, para serem utilizadas na gerao do registro 0175 do Sped Fiscal */

create or replace
TRIGGER ALTERA_END_FILIAL_SPED
AFTER UPDATE
ON ENDEFILI FOR EACH ROW
DECLARE  
  V_NRSEQALTPARTSPED NUMBER;
  V_DTOPER           DATE;
  V_CDMUNICIBGE      VARCHAR2(10);
  V_CDPAISBACEN      VARCHAR(4);
BEGIN
  IF UPDATING THEN 
    IF (((:OLD.CDPAIS <> :NEW.CDPAIS) OR (:NEW.CDPAIS IS NULL)) AND (:OLD.CDPAIS IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;

       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;
        
       BEGIN
            SELECT CDPAISBACEN
              INTO V_CDPAISBACEN
              FROM PAIS
             WHERE CDPAIS = :OLD.CDPAIS;
       EXCEPTION 
            WHEN NO_DATA_FOUND THEN
                 V_CDPAISBACEN := NULL;
       END;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'L'||:OLD.CDFILIAL
               AND CDCAMPO = '04'
               AND DTALTERACAO < V_DTOPER;
       END;
        
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'L'||:OLD.CDFILIAL,'04',V_DTOPER,V_CDPAISBACEN);
    END IF;
    
    IF (((:OLD.CDMUNICIPIO <> :NEW.CDMUNICIPIO) OR (:NEW.CDMUNICIPIO IS NULL)) AND (:OLD.CDMUNICIPIO IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;
       
       BEGIN
            SELECT CDMUNICIBGE
              INTO V_CDMUNICIBGE
              FROM MUNICIPIO
             WHERE CDMUNICIPIO = :OLD.CDMUNICIPIO
               AND CDPAIS      = :OLD.CDPAIS
               AND SGESTADO    = :OLD.SGESTADO;
       EXCEPTION 
            WHEN NO_DATA_FOUND THEN
                 V_CDMUNICIBGE := NULL;
       END;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'L'||:OLD.CDFILIAL
               AND CDCAMPO = '08'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'L'||:OLD.CDFILIAL,'08',V_DTOPER,V_CDMUNICIBGE);
    END IF;
    
    IF (((:OLD.DSENDEFILI <> :NEW.DSENDEFILI) OR (:NEW.DSENDEFILI IS NULL)) AND (:OLD.DSENDEFILI IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;

       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'L'||:OLD.CDFILIAL
               AND CDCAMPO = '10'
               AND DTALTERACAO < V_DTOPER;
       END;

       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'L'||:OLD.CDFILIAL,'10',V_DTOPER,:OLD.DSENDEFILI);
    END IF;

    IF (((:OLD.DSCOMPENDFIL <> :NEW.DSCOMPENDFIL) OR (:NEW.DSCOMPENDFIL IS NULL)) AND (:OLD.DSCOMPENDFIL IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'L'||:OLD.CDFILIAL
               AND CDCAMPO = '12'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'L'||:OLD.CDFILIAL,'12',V_DTOPER,:OLD.DSCOMPENDFIL);    
    END IF;
    
    IF (((:OLD.NMBAIRFILI <> :NEW.NMBAIRFILI) OR (:NEW.NMBAIRFILI IS NULL)) AND (:OLD.NMBAIRFILI IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;

       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'L'||:OLD.CDFILIAL
               AND CDCAMPO = '13'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'L'||:OLD.CDFILIAL,'13',V_DTOPER,:OLD.NMBAIRFILI);
    END IF;
  END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ALTERA_END_FILIAL_SPED','5.85.000'); END;
/