import { Utilities } from '@/util/Utilities';
import {
    Button, Checkbox, DialogService, FileInput, Form, IterableComponentRender, LoadingService, Row, Textarea,
} from '@zeedhi/common';
import {
    Http, IDictionary, IEventParam, Metadata,
} from '@zeedhi/core';
import { IterableCarousel, TekGrid } from '@zeedhi/teknisa-components-common';
import { TekIterableComponentRender } from '@zeedhi/teknisa-components-vuetify';
import FileUpload from '../FileUpload';

export class Fm00040000ExecucaoAuditoriaController {
    public visibilidadeTemplate: boolean = true;

    public currentRow: any = '';

    public nomeAuditoria: string = '';

    public situacaoAuditoria: string = '';

    public textArea: boolean = true;

    public checkbox: boolean = true;

    public botaoAnexar: boolean = true;

    public btnSalvarRascunho: boolean = false;

    public btnFinalizarAuditoria: boolean = false;

    public btnApagarImg: boolean = true;

    get visibilidadeDoFrame() {
        return !this.visibilidadeTemplate;
    }

    public visualizarExecucao({ row }: IEventParam<TekGrid>) {
        this.currentRow = row;
        this.visibilidadeTemplate = false;
        this.nomeAuditoria = row.NMAUDITORIA;
        this.formatarSituacao(row.IDSITUACAOAUDIT);
        this.onMountedCategorias({ row });
        this.onMountedValidacoes({ row });
    }

    public formatarSituacao(id: string) {
        if (id === '1') {
            this.situacaoAuditoria = "<span  style='background-color: #dee2e6; color: #ff6700;'>Pendente</span>";
        } else if (id === '2') {
            this.situacaoAuditoria = "<span  style='background-color: #dee2e6; color: #023e8a;'>Em Andamento</span>";
        } else {
            this.situacaoAuditoria = "<span  style='background-color: #dee2e6; color: green;'>Concluído</span>";
        }
    }

    public onMountedCategorias({ row }: any) {
        Metadata.getInstance<TekIterableComponentRender>('iterable-categorias').datasource.setFilter({
            NRAUDITORIA: row.NRAUDITORIA,
        });
    }

    public onMountedValidacoes({ row }: any) {
        if (row.IDSITUACAOAUDIT === '1') {
            this.btnFinalizarAuditoria = true;
            this.btnSalvarRascunho = true;
            this.botaoAnexar = false;
            this.textArea = false;
            this.checkbox = false;
            this.btnApagarImg = false;
        } else if (row.IDSITUACAOAUDIT === '2') {
            this.btnFinalizarAuditoria = false;
            this.btnSalvarRascunho = false;
            this.botaoAnexar = false;
            this.textArea = false;
            this.checkbox = false;
            this.btnApagarImg = true;
        } else {
            this.btnFinalizarAuditoria = true;
            this.btnSalvarRascunho = true;
            this.botaoAnexar = true;
            this.textArea = true;
            this.checkbox = true;
            this.btnApagarImg = false;
        }
    }

    public voltarPaginaInicial() {
        this.visibilidadeTemplate = true;
    }

    public getTopicos({ component }: IEventParam<IterableComponentRender>) {
        component.datasource.setFilter({
            NRCATEGORIAAUDIT: component.name.split('_')[1],
            NRAUDITORIA: this.currentRow.NRAUDITORIA,
        });
    }

    public getCriterios({ component }: IEventParam<TekIterableComponentRender>) {
        component.datasource.setFilter({
            NRTOPICOAUDIT: component.name.split('_')[1],
            NRAUDITORIA: this.currentRow.NRAUDITORIA,
        });
    }

    /* Nesta função também contém a tratativa para alterar o status do Item (IDREALIZADO) para 'S'
    tanto no momento da iniciação automática quanto em uma tarefa já em andamento */
    public async changeCheckbox({ component }: any) {
        const iterableCheckbox = Metadata.getInstance<TekIterableComponentRender>(`iterable-criterios_${component.name.split('_')[2]}`);
        const iterableTopicos = Metadata.getInstance<TekIterableComponentRender>(`iterable-topicos_${component.name.split('_')[3]}`);

        const chkboxS: IDictionary = [];
        const chkboxN: IDictionary = [];

        iterableTopicos.datasource.data?.forEach((topic: IDictionary) => {
            /* eslint-disable */
            if (topic.NRTOPICOAUDIT === parseInt(component.name.split('_')[2])) {
                iterableCheckbox.datasource.data?.forEach((itens: IDictionary) => {
                    const checkbox = Metadata.getInstance<Checkbox>(`checkbox_${itens.NRRELACRESULTCRIT}_${itens.NRTOPICOAUDIT}_${itens.NRCATEGORIAAUDIT}`);
                    if (this.currentRow.IDTIPOMARCACAO === 'U' && checkbox.name !== component.name && checkbox.value === 'S') {
                        checkbox.value = 'N';
                    }

                    if (checkbox.value === 'S') {
                        chkboxS.push(itens.NRRELACRESULTCRIT);
                    } else {
                        chkboxN.push(itens.NRRELACRESULTCRIT);
                    }
                });
            }
            /* eslint-enable */
        });

        if (this.currentRow.IDSITUACAOAUDIT === '1') {
            await this.iniciarOuFinalizarAuditoria('2');
            this.btnSalvarRascunho = false;
            this.btnFinalizarAuditoria = false;
            this.alterarStatusCriterio(chkboxS, chkboxN);
        } else if (this.currentRow.IDSITUACAOAUDIT === '2') {
            this.alterarStatusCriterio(chkboxS, chkboxN);
        }
    }

    public alterarStatusCriterio(chkboxS: any, chkboxN: any) {
        Http.post('/alterarStatusCriterio', {
            criteriosN: chkboxN,
            criteriosS: chkboxS,
        }).then(() => {
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });
    }

    public async finalizarAuditoria() {
        await this.salvarRascunhoObs();
        this.iniciarOuFinalizarAuditoria('3');
    }

    public iniciarOuFinalizarAuditoria(id: string) {
        const gridAuditorias = Metadata.getInstance<TekGrid>('TekGrid_template_tek-grid-execucao-auditoria');
        LoadingService.show();
        Http.post('/iniciarOuFinalizarAuditoria', {
            IDSITUACAOAUDIT: id,
            NRAUDITORIA: this.currentRow.NRAUDITORIA,
        }).then(() => {
            Utilities.showSuccessMessage();
            this.currentRow.IDSITUACAOAUDIT = id;
            gridAuditorias.datasource.get();
            this.onMountedValidacoes({ row: this.currentRow });
            this.formatarSituacao(id);
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        })
        .finally(() => {
            LoadingService.hide();
        });
    }

    public validationsTextArea({ component }: IEventParam<Textarea>) {
        if (this.currentRow.IDOBRIGAOBSERVACAO === 'S') {
            component.addValidation('required', {});
        } else {
            component.removeValidation('required');
        }
    }

    public abrirAnexoImagem({ component }: IEventParam<Button>) {
        component.disabled = true;
        /* esvaziando o input e o carrossel de anexar ao abrir um novo anexo */
        Metadata.getInstance<IterableCarousel>(`carousel-imagens_${component.name.split('_')[1]}`).iterable.datasource.updateData([]);
        Metadata.getInstance<FileInput>(`file-input-anexar-imagem_${component.name.split('_')[1]}`).value = null;

        const form = Metadata.getInstance<Form>(`form-anexar-fotos_${component.name.split('_')[1]}`);
        const row = Metadata.getInstance<Row>(`row-btn-can-ane_${component.name.split('_')[1]}`);
        const iterableImgAnexadas = Metadata.getInstance<IterableCarousel>(`carousel-imagens-anexadas_${component.name.split('_')[1]}_${component.name.split('_')[2]}`);

        form.isVisible = true;
        row.isVisible = true;
        iterableImgAnexadas.isVisible = false;
    }

    public fecharAnexoImagem({ component }: IEventParam<Button>) {
        this.botaoAnexar = false;
        const form = Metadata.getInstance<Form>(`form-anexar-fotos_${component.name.split('_')[1]}`);
        const row = Metadata.getInstance<Row>(`row-btn-can-ane_${component.name.split('_')[1]}`);
        const iterableImgAnexadas = Metadata.getInstance<IterableCarousel>(`carousel-imagens-anexadas_${component.name.split('_')[1]}_${component.name.split('_')[2]}`);
        const iterableImgs = Metadata.getInstance<IterableCarousel>(`carousel-imagens_${component.name.split('_')[1]}`);

        form.isVisible = false;
        row.isVisible = false;
        iterableImgAnexadas.isVisible = true;
        iterableImgs.isVisible = false;
    }

    public exibirImagemAnexada({ component }: any) {
        const carousel = Metadata.getInstance<IterableCarousel>(`carousel-imagens_${component.name.split('_')[1]}`);
        carousel.iterable.datasource.updateData([]);
        const imagens: any = [];

        if (component.value.length) {
            carousel.isVisible = true;
            component.value.forEach((elemento: any, posicao: any) => {
                imagens.push({
                    id: posicao,
                    src: window.URL.createObjectURL(elemento),
                });
            });
        } else {
            carousel.isVisible = false;
        }
        carousel.iterable.datasource.updateData(imagens);
    }

    public async anexarImagens({ component }: IEventParam<Button>) {
        const imagensConvertidas = await FileUpload.converterImagens(`file-input-anexar-imagem_${component.name.split('_')[1]}`);
        const fileInput = Metadata.getInstance<FileInput>(`file-input-anexar-imagem_${component.name.split('_')[1]}`);
        const iterableImagensAnexadas = Metadata.getInstance<IterableCarousel>(`carousel-imagens-anexadas_${component.name.split('_')[1]}_${component.name.split('_')[2]}`);

        LoadingService.show();
        if (fileInput.value) {
            Http.post('/anexarImagemAuditoria', {
                IMAGENS: imagensConvertidas,
                NRAUDITORIA: this.currentRow.NRAUDITORIA,
                NRCATEGORIAAUDIT: component.name.split('_')[2],
                NRTOPICOAUDIT: component.name.split('_')[1],
            }).then(() => {
                Utilities.showSuccessMessage();
                this.fecharAnexoImagem({ component });
                iterableImagensAnexadas.iterable.datasource.get();
                if (this.currentRow.IDSITUACAOAUDIT === '1') {
                    this.iniciarOuFinalizarAuditoria('2');
                    this.situacaoAuditoria = "<span  style='background-color: #dee2e6; color: #023e8a;'>Em Andamento</span>";
                    this.btnSalvarRascunho = false;
                }
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            Utilities.alertMessage('Nenhuma imagem foi anexada', 'error');
        }
    }

    public onMountedImagensAnexadas({ component }: IEventParam<IterableCarousel>) {
        component.iterable.datasource.setFilter({
            NRAUDITORIA: this.currentRow.NRAUDITORIA,
            NRCATEGORIAAUDIT: component.name.split('_')[2],
            NRTOPICOAUDIT: component.name.split('_')[1],
        });
    }

    public dialogExcluirFotosAuditoria({ component, event }: any) {
        event.preventDefault();
        DialogService.show({
            name: `dialog-apagar-${component.name}`,
            type: 'warning',
            title: 'Atenção',
            text: 'Obs: Esta imagem será excluída. Deseja continuar?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: `sim-${component.name}`,
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.excluirFoto({ component });
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public async excluirFoto({ component }: IEventParam<Button>) {
        const iterableImagensAnexadas = Metadata.getInstance<IterableCarousel>(`carousel-imagens-anexadas_${component.name.split('_')[1]}_${component.name.split('_')[2]}`);

        LoadingService.show();
        Http.post('/excluirImagemAuditoria', {
            NRFOTORESULTAUDIT: component.name.split('_')[3],
        }).then(() => {
            iterableImagensAnexadas.iterable.datasource.get();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public salvarRascunhoObs() {
        LoadingService.show();
        const iterableCategorias = Metadata.getInstance<IterableComponentRender>('iterable-categorias');
        const arrayObs: IDictionary = [];

        iterableCategorias.datasource.data.forEach((cat: any) => {
            const iterableTopicos = Metadata.getInstance<TekIterableComponentRender>(`iterable-topicos_${cat.NRCATEGORIAAUDIT}`);
            iterableTopicos.datasource.data?.forEach((topic: any) => {
                const obs = Metadata.getInstance<Textarea>(`text-area-observacao_${topic.NRTOPICOAUDIT}_${topic.NRRELACCATTOPIC}`).value;

                if (obs !== '' && obs !== null && obs !== undefined) {
                    arrayObs.push({
                        DSOBSERVACAO: obs,
                        NRRELACCATTOPIC: topic.NRRELACCATTOPIC,
                        NRAUDITORIA: this.currentRow.NRAUDITORIA,
                    });
                }
            });
        });

        Http.post('/salvarRascunhoAuditoria', arrayObs).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
