import {
    Button, DialogService, FileInput, Form, IGridEvent, LoadingService, Modal, ModalService, Select, TextInput, Text,
} from '@zeedhi/common';
import { Http, IDictionary, Metadata } from '@zeedhi/core';
import { IterableCarousel, TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';
import FileUpload from '../FileUpload';

export class FmtAtivosInsumosInsumosController {
    private modalSalvarInsumos!: Modal;

    private modalAdicionarImagens!: Modal;

    private modalExcluirImagens!: Modal;

    private tituloModal: string = '';

    private carouselVisibility: boolean = false;

    private nrRowAtual: any;

    public async abrirModal() {
        this.modalSalvarInsumos = await ModalService.createFromJsonPost('', { jsonPath: '/fmt_ativosInsumos/modal/fmt_ativos_insumos_salvar_insumo' });
        this.modalSalvarInsumos.show();
    }

    public async abrirModalAdicionar() {
        this.tituloModal = 'Adicionar Insumo';
        await this.abrirModal();
    }

    public async abrirModalEdicao({ row }: IGridEvent) {
        this.tituloModal = 'Editar Insumo';
        await this.abrirModal();

        const inputNrRow = Metadata.getInstance<TextInput>('NRROW');
        const inputNome = Metadata.getInstance<TextInput>('InputNomeInsumo');
        const inputCodigo = Metadata.getInstance<TextInput>('InputCodigoInsumo');
        const selectUniMedida = Metadata.getInstance<Select>('SelectUnidadeMedidaInsumo');
        const selectProduto = Metadata.getInstance<Select>('SelectProdutoInsumo');

        inputNrRow.value = row.NRINSUMO;
        inputNome.value = row.NMINSUMO;
        inputCodigo.value = row.CDINSUMO;
        selectUniMedida.setValue(row.NRUNIDADEMEDIDA);
        selectProduto.setValue(row.CDPRODUTO);
    }

    public fecharModal() {
        this.modalSalvarInsumos.hide();
        this.modalSalvarInsumos?.destroy();
    }

    public async salvarInsumo() {
        const form = Metadata.getInstance<Form>('form-salvar-insumo');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-insumos');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/salvarInsumo', {
                NRROW: form.value.NRROW,
                NMINSUMO: form.value.InputNomeInsumo,
                CDINSUMO: form.value.InputCodigoInsumo,
                NRUNIDADEMEDIDA: form.value.SelectUnidadeMedidaInsumo,
                CDPRODUTO: form.value.SelectProdutoInsumo,
            }).then(() => {
                Utilities.showSuccessMessage();
                grid.datasource.get();
                this.fecharModal();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public messageConfirmDelete({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'FmtAtivosInsumosInsumosController.deleteInsumos', 'Excluir Insumos', 'Deseja realmente excluir os registros selecionados?');
    }

    public deleteInsumos() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-insumos');

        LoadingService.show();
        Http.post('/deleteInsumos', {
            ROWS: grid.selectedRows.map((el) => el.NRINSUMO),
        }).then(() => {
            Utilities.showSuccessMessage();
            grid.datasource.get();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            grid.selectedRows = [];
            DialogService.hide();
            LoadingService.hide();
        });
    }

    public async abrirModalAdicionarImagens({ row }: any) {
        this.modalAdicionarImagens?.destroy();
        this.modalAdicionarImagens = await ModalService.createFromJsonPost('', { jsonPath: '/fmt_ativosInsumos/modal/fmt_ativos_insumos_adicionar_img_insumo' });
        this.nrRowAtual = row.NRINSUMO;
        this.modalAdicionarImagens.show();
    }

    public fecharModalAdicionarImagens() {
        this.modalAdicionarImagens.hide();
        this.modalAdicionarImagens?.destroy();
    }

    public async adicionarImagens() {
        const imgs = await this.updloadPictures('FileInputFotosInsumo');

        LoadingService.show();
        Http.post('/insertFotosInsumo', {
            NRINSUMO: this.nrRowAtual,
            FOTOS: imgs,
        }).then(() => {
            Utilities.showSuccessMessage();
            this.fecharModalAdicionarImagens();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            DialogService.hide();
            LoadingService.hide();
        });
    }

    public async abrirModalExcluirImagens({ row }: any) {
        this.modalExcluirImagens?.destroy();
        this.modalExcluirImagens = await ModalService.createFromJsonPost('', { jsonPath: '/fmt_ativosInsumos/modal/fmt_ativos_insumos_excluir_img_insumo' });
        this.nrRowAtual = row.NRINSUMO;
        this.modalExcluirImagens.show();
        setTimeout(() => {
            const carouselImagens = Metadata.getInstance<IterableCarousel>('carousel-imagens-insumo');
            this.carregarFotosInsumo({ component: carouselImagens });
        }, 300);
    }

    public carregarFotosInsumo({ component }: any) {
        const botaoApagar = Metadata.getInstance<Button>('botao-excluir-imagem');
        LoadingService.show();
        this.getFotosInsumo(this.nrRowAtual).then((response: any) => {
            if (response.data.data.length > 0) {
                component.iterable.datasource.data = [];
                response.data.data.forEach((dados: IDictionary) => {
                    component.iterable.datasource.data.push({
                        NRIMGINSUMO: dados.NRIMGINSUMO,
                        DSCAMINHO: dados.DSCAMINHO,
                    });
                });
            } else {
                const txtSemRes = Metadata.getInstance<Text>('sem-resultado-imagens-insumo');
                txtSemRes.isVisible = true;
                component.isVisible = false;
                botaoApagar.isVisible = false;
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public getFotosInsumo(NRROW: any) {
        return Http.post('/getFotosInsumo', {
            NRINSUMO: NRROW,
        });
    }

    public excluirImagens() {
        const carousel = Metadata.getInstance<IterableCarousel>('carousel-imagens-insumo');
        const imgs = carousel.iterable.datasource.data;
        const [imgDeletada] = imgs.filter((value: any, index: any) => index === carousel.currentSlide);

        LoadingService.show();
        this.deleteFotoInsumo(imgDeletada).then(() => {
            const data = imgs.filter((value: any, index: any) => index !== carousel.currentSlide);
            carousel.iterable.datasource.updateData(data);
            if (data.length === 0) {
                const txtSemRes = Metadata.getInstance<Text>('sem-resultado-imagens-ativo');
                const botaoApagar = Metadata.getInstance<Button>('botao-excluir-imagem');
                txtSemRes.isVisible = true;
                botaoApagar.isVisible = false;
                carousel.isVisible = false;
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public deleteFotoInsumo(imgDeletada: any) {
        return Http.post('/deleteFotoInsumo', {
            NRIMGINSUMO: imgDeletada.NRIMGINSUMO,
        });
    }

    public fecharModalExcluirImagens() {
        this.modalExcluirImagens.hide();
        this.modalExcluirImagens?.destroy();
    }

    public mostrarFotoInsumo({ component }: any) {
        const carouselFotos = Metadata.getInstance<IterableCarousel>('CarouselFotosInsumo');
        carouselFotos.iterable.datasource.updateData([]);
        const imagens: any = [];
        component.value.forEach((element: any, pos: any) => {
            imagens.push({
                id: `numero_${pos}`,
                src: window.URL.createObjectURL(element),
            });
        });
        carouselFotos.iterable.datasource.updateData(imagens);
        this.carouselVisibility = component.value.length > 0;
    }

    public async updloadPictures(name: string) {
        const fileInputObject = Metadata.getInstance<FileInput>(name).value;
        let arquivos: any = [];
        if (fileInputObject && fileInputObject.length > 0) {
            const types: IDictionary = ['image/jpg', 'image/jpeg', 'image/png'];
            const buildFilesPromises = fileInputObject.map((file: any) => {
                if (types.includes(file.type)) {
                    return FileUpload.buildFileSendObject(file);
                }
                return [];
            });
            await Promise.all(buildFilesPromises).then((files: any) => {
                arquivos = files;
            });
          }
        return arquivos;
    }
}
